<?php
namespace Woocommerce\Moip\Fields\Credit_Card;

if ( ! function_exists( 'add_action' ) ) {
	exit( 0 );
}

use Woocommerce\Moip\Core;
use Woocommerce\Moip\Model\Setting;
use Woocommerce\Moip\Model\Custom_Gateway;

class Config
{
	public static function not_found()
	{
		return array(
			'title' => __( 'Enable credit card option!', 'woo-moip-official' ),
			'type'  => 'title',
			'description' => sprintf(
				__( 'Click the link to go back and activate your credit card: %s' , 'woo-moip-official' ),
				self::get_general_url()
			),
		);
	}

	public static function not_found_cc()
	{
		return array(
			'title' => __( 'Credit card setup is not yet available for the wirecard checkout!', 'woo-moip-official' ),
			'type'  => 'title'
		);
	}

	public static function get_general_url()
	{
		$url = admin_url( 'admin.php?page=wc-settings&tab=checkout&section=woo-moip-official&wirecard-tab=wbo-general' );
		return '<a href="' . esc_url( $url ) . '">' . __( 'General', 'woo-moip-official' ) . '</a>';
	}

	public static function section_installments()
	{
		return array(
			'title' => __( 'Credit Card Settings', 'woo-moip-official' ),
			'type'  => 'title',
		);
    }

	public static function save_credit_card_option()
    {
    	return array(
			'title'       => __( 'Save Credit Card', 'woo-moip-official' ),
			'description' => __( 'Show option to save the card number in transparent checkout.', 'woo-moip-official' ),
			'desc_tip'    => true,
			'type'        => 'checkbox',
			'label'       => __( 'Show Option', 'woo-moip-official' ),
			'default'     => 'no',
			'custom_attributes' => array(
				'data-field' => 'credit-card-option',
			),
		);
    }

	public static function field_credit_card_installments( $field )
	{
		$model        = new Custom_Gateway();
		$installments = array();

		$installments['enabled'] = array(
			'title'             => __( 'Installments settings', 'woo-moip-official' ),
			'type'              => 'checkbox',
			'label'             => __( 'Enable Installments settings', 'woo-moip-official' ),
			'default'           => 'no',
			'custom_attributes' => array(
				'data-field' => 'installments',
			),
		);

		$installments['installment'] = array(
			'title'       => __( 'Minimum installment', 'woo-moip-official' ),
			'type'        => 'text',
			'description' => __( 'Amount of the minimum installment to be applied to the card.', 'woo-moip-official' ),
			'desc_tip'    => true,
			'placeholder' => '0,00',
			'custom_attributes' => array(
				'data-mask'         => '##0,00',
				'data-mask-reverse' => true,
			),
		);

		$installments['maximum'] = array(
			'title'       => __( 'Maximum installments number', 'woo-moip-official' ),
			'type'        => 'select',
			'description' => __( 'Force a maximum number of installments for payment.', 'woo-moip-official' ),
			'desc_tip'    => true,
			'default'     => 12,
			'options'     => $model->get_installment_options(),
			'custom_attributes' => array(
				'data-action' => 'installments-maximum',
			),
		);

		$installments['general'] = array(
			'title'       => __( 'Interest per installment', 'woo-moip-official' ),
			'type'        => 'installments',
			'description' => __( 'Define interest for each installment.', 'woo-moip-official' ),
			'desc_tip'    => false,
		);

		$installments['interest'] = array(
			'title'       => __( 'Interest', 'woo-moip-official' ),
			'type'        => 'text',
			'description' => __( 'Interest to be applied to the installment.', 'woo-moip-official' ),
			'desc_tip'    => true,
			'placeholder' => '0,00',
		);

		return $installments[ $field ];
	}

	public static function cc_additional_fields()
	{
		return array(
			'title' => __( 'Additional Fields', 'woo-moip-official' ),
			'type'  => 'title',
		);
	}

	public static function field_wirecard_cpf_holder()
	{
		return array(
			'title'       => __( 'CPF', 'woo-moip-official' ),
			'type'        => 'checkbox',
			'label'       => __( 'Enable CPF field', 'woo-moip-official' ),
			'default'     => 'no',
			'description' => __( 'Add CPF field to credit card tab for risk analysis.(for transparent checkout only).', 'woo-moip-official' ),
			'desc_tip'    => false,
			'custom_attributes' => array(
				'data-field' => 'render-cpf-field',
			),
		);
	}

	public static function field_wirecard_birth_holder()
	{
		return array(
			'title'       => __( 'Date Birth', 'woo-moip-official' ),
			'type'        => 'checkbox',
			'label'       => __( 'Enable date birth field', 'woo-moip-official' ),
			'default'     => 'no',
			'description' => __( 'Add date birth field to credit card tab for risk analysis.(for transparent checkout only).', 'woo-moip-official' ),
			'desc_tip'    => false,
			'custom_attributes' => array(
				'data-field' => 'render-birth-field',
			),
		);
	}

	public static function field_wirecard_phone_holder()
	{
		return array(
			'title'       => __( 'Phone', 'woo-moip-official' ),
			'type'        => 'checkbox',
			'label'       => __( 'Enable phone field', 'woo-moip-official' ),
			'default'     => 'no',
			'description' => __( 'Add phone field to credit card tab for risk analysis.(for transparent checkout only).', 'woo-moip-official' ),
			'desc_tip'    => false,
			'custom_attributes' => array(
				'data-field' => 'render-phone-field',
			),
		);
	}

	public static function get_fields()
	{
		$settings = Setting::get_instance();
		$values   = array(
			'not_found'  => self::not_found(),
		);

		if ( $settings->is_checkout_wirecard() ) {
			$values = array(
				'not_found_cc'  => self::not_found_cc(),
			);

			return $values;
		}

		if ( $settings->is_active_credit_card() ) {
			$values   = array(
				'section_installments'  => self::section_installments(),
                //'save_credit_card'      => self::save_credit_card_option(),
				'installments_enabled'  => self::field_credit_card_installments( 'enabled' ),
				'installments_minimum'  => self::field_credit_card_installments( 'installment' ),
				'installments_maximum'  => self::field_credit_card_installments( 'maximum' ),
				'installments'          => self::field_credit_card_installments( 'general' ),
				'cc_additional_fields'  => self::cc_additional_fields(),
				'wirecard_cpf_holder'   => self::field_wirecard_cpf_holder(),
				'wirecard_birth_holder' => self::field_wirecard_birth_holder(),
				'wirecard_phone_holder' => self::field_wirecard_phone_holder()
			);
		}

		return $values;
	}
}
