<?php
namespace Woocommerce\Moip\Model;

if ( ! function_exists( 'add_action' ) ) {
	exit( 0 );
}

use Woocommerce\Moip\Core;
use Woocommerce\Moip\Model\Setting;
use Woocommerce\Moip\Helper\Utils;

class Payment_Split
{
    private function _get_app_header()
    {
        $settings       = Setting::get_instance();
        $wirecard_token = $settings->wirecard_manual_token;
        $wirecard_key   = $settings->wirecard_manual_key;
        $credentials    = base64_encode( $wirecard_token.':'.$wirecard_key );

        if ( empty( $wirecard_token ) && empty( $wirecard_key ) ) {
            ob_start();
			printf('<div id="message" class="error"><p>%s</p></div>',
			__( 'Wirecard: Before generating the APP you need to save the settings!', 'woo-moip-official' ) );

            return '';
        }

        $args = array(
            'authorization: Basic '. $credentials,
            'content-type: application/json'
        );

		return $args;
    }

    public function set_wirecard_split_body()
    {
        $settings          = Setting::get_instance();
        $split_name        = __( 'Wirecard Brazil Official Split', 'woo-moip-official' );
        $split_description = __( 'Wirecard Brazil Official Payment Split', 'woo-moip-official' );
        $get_name          = $settings->wirecard_split_name;
        $get_description   = $settings->wirecard_split_description;

        if ( $get_name ) {
            $split_name = $get_name;
        }

        if ( $get_description ) {
            $split_description = $get_description;
        }

        $args = array(
            'name'        => $split_name,
            'description' => $split_description,
            'site'        => site_url(),
            'redirectUri' => rest_url( Core::SPLIT_REST_ROUTE.'/callback' )
		);
		return $args;
    }

    public function create_wirecard_split_app()
    {
        $header = $this->_get_app_header();

        if ( empty( $header ) ) {
            return;
        }

        $response = wp_remote_post(
			Utils::get_url_endpoint() . '/v2/channels/',
			[
                $header,
                'body'    => json_encode( $this->set_wirecard_split_body() ),
				'timeout' => 30,
            ]
		);

        $response_body = wp_remote_retrieve_body( $response );
		$response      = json_decode( $response_body );

        if ( is_wp_error( $response ) ) {
            return $response->get_error_message();
        }

        update_option( 'wirecard_split_app_id', $response->id ) ;
        update_option( 'wirecard_split_accesstoken', $response->accessToken );
        update_option( 'wirecard_split_secret', $response->secret );
        update_option( 'wirecard_split_siteurl', $response->website );
        update_option( 'wirecard_split_redirecturl', $response->redirectUri );
    }
}
